@@ -1,6 +1,6 @@
 require 5.006_001;
 BEGIN {
-  $Orignal::VERSION = "0.03";
+  $Orignal::VERSION = "0.04";
 }
 package Orignal;
 use Carp();
@@ -437,11 +437,11 @@ sub _initialize {
 __END__
 =pod
 
-=head1 Orignal 
+=head1 NAME 
 
 Orignal - Very simple properties/attributes/fields for Perl
 
-=head1 SYNOPSIS
+head1 SYNOPSIS
 
   package house;
   use parent  qw(Orignal);
